package com.chelvc.cloud.vehicle.server.controller;

import java.util.List;

import com.chelvc.cloud.vehicle.client.constant.ReserveStatus;
import com.chelvc.cloud.vehicle.client.dto.MerchantReservationDTO;
import com.chelvc.cloud.vehicle.client.dto.ReservationDTO;
import com.chelvc.cloud.vehicle.client.dto.UserReservationDTO;
import com.chelvc.cloud.vehicle.client.param.ReservationModifyParam;
import com.chelvc.cloud.vehicle.client.param.ReservationPagingParam;
import com.chelvc.cloud.vehicle.client.param.ReservationQueryParam;
import com.chelvc.cloud.vehicle.server.service.ReservationService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 预约业务接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class ReservationController {

    private final ReservationService reservationService;

    /**
     * 新增预约信息
     *
     * @param merchantId 商家ID
     * @param param      预约参数
     */
    @PostMapping("/reservation/addReservation")
    public void addReservation(@RequestParam("merchantId") Long merchantId, @RequestBody ReservationModifyParam param) {
        reservationService.addReservation(merchantId, param);
    }

    /**
     * 查询用户预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    @GetMapping("/reservation/listUserReservations")
    public List<ReservationDTO> listUserReservations(ReservationQueryParam param) {
        return reservationService.listUserReservations(param);
    }

    /**
     * 取消预约
     *
     * @param id 预约记录逐渐主键
     */
    @DeleteMapping("/reservation")
    public void deleteReservation(@RequestParam("id") Long id) {
        reservationService.deleteReservation(id);
    }

    /**
     * 查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    @GetMapping("/reservation/getReservationPaging")
    public Pagination<ReservationDTO> getReservationPaging(ReservationPagingParam param) {
        return reservationService.getReservationPaging(param);
    }

    /**
     * 查询商家被预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    @GetMapping("/reservation/listMerchantReservations")
    public List<ReservationDTO> listMerchantReservations(ReservationQueryParam param) {
        return reservationService.listMerchantReservations(param);
    }

    /**
     * 更新预约单的状态
     *
     * @param id     预约单ID
     * @param status 预约单的状态
     */
    @PutMapping("/reservation/updateReservationsStatus")
    public void updateReservationsStatus(@RequestParam("id") Long id, @RequestParam("status") ReserveStatus status) {
        reservationService.updateReservationsStatus(id, status);
    }


    /**
     * 预约详情
     *
     * @param id
     * @return
     */
    @GetMapping("/reservation/getDetail")
    public ReservationDTO getDetail(@RequestParam("id") Long id) {
        return reservationService.getDetail(id);
    }



    /**
     * 商家端分页查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    @GetMapping("/reservation/getMerchantList")
    public Pagination<MerchantReservationDTO> getMerchantReservationPaging(ReservationPagingParam param) {
        return reservationService.getMerchantReservationPaging(param);
    }


    /**
     * 用户端分页查询预约
     *
     * @param param 查询参数
     * @return 预约分页信息
     */
    @GetMapping("/reservation/getUserReservation")
    public Pagination<UserReservationDTO> getUserReservationPaging(ReservationPagingParam param) {
        return reservationService.getUserReservationPaging(param);
    }
}
